/**
 * @file
 * Processes links with the prefetch class.
 */

(function ($, Drupal) {

  "use strict";

  /**
   * Process links.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.prefetch_cache = {
    attach: function (context, settings) {

      $('a.prefetch-cache').once('prefetch-link').each(function () {

        var link = $(this);
        var href = link.attr('href');

        if (href.length > 0) {
          href = prepare_href_query(href);
          href += 'prefetch_cache_request=1';

          $.ajax({
            url: href,
            // We want to simulate a normal request and not an ajax request.
            // JQuery Ajax calls will set the 'X-Requested-With' header to
            // 'XMLHttpRequest' empty string, which is later used by Drupal to
            // identity the request as ajax one. Therefor we set this header to
            // an empty string.
            beforeSend: function( xhr ) {
              xhr.setRequestHeader('X-Requested-With', {toString: function(){ return ''; }});
            }
          })
            .done(function (response) {
              response = $.parseJSON(response);

              if (response.hasOwnProperty('prefetch_cache_token_id')) {
                href = link.attr('href');
                href = prepare_href_query(href);
                href += 'prefetch_cache_token_id=' + response.prefetch_cache_token_id;

                link.attr('href', href);
              }
            });
        }

      });

      function prepare_href_query(href) {
        if (href.indexOf('?') === -1) {
          href += '?';
        }
        else {
          href += '&';
        }
        return href;
      }
    }
  };

})(jQuery, Drupal);